@@ -10,7 +10,7 @@ describe 'mistral::db::mysql' do
   end
 
   let :facts do
-    { :osfamily => 'Debian' }
+    OSDefaults.get_facts({ :osfamily => 'Debian' })
   end
 
   let :params do
