@@ -32,7 +32,7 @@ describe 'mistral::db::sync' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
